import { computed, shallowRef } from "vue";
import { ContentApis, ContentConfig } from "/@/components/PageContent";
import { FormConfig } from "/@/components/PageSearch";
import { cloneDeep } from "lodash";

interface InsertBusinessField {
  index?: number;
  name?: string;
  code?: string;
}

interface IContentOptions {
  apis: ContentApis;
  sourceConfig: ContentConfig;
  insertBusinessField?: InsertBusinessField;
}

const defaultInsertBusinessField: InsertBusinessField = {
  index: 2,
  name: "relaComName",
  code: "relaComNo"
};

export function useBusinessContent(options: IContentOptions) {
  const {
    sourceConfig,
    apis,
    insertBusinessField = defaultInsertBusinessField
  } = options;
  const contentConfig = cloneDeep(sourceConfig) as ContentConfig;
  const { columns: beforeColumns } = contentConfig;

  const {
    name = defaultInsertBusinessField.name,
    code = defaultInsertBusinessField.code,
    index = defaultInsertBusinessField.index
  } = insertBusinessField;

  const afterColumns = beforeColumns.splice(index);

  // function render(row: Record<string, string>, prop: string) {
  //   return row[prop] ? row[prop] : "--";
  // }
  // beforeColumns.push({
  //   prop: code,
  //   label: "业务公司编号",
  //   minWidth: "155px",
  //   cellRenderer: ({ row }) => render(row, code)
  // });
  //
  // beforeColumns.push({
  //   prop: name,
  //   label: "业务公司名称",
  //   minWidth: "155px",
  //   cellRenderer: ({ row }) => render(row, name)
  // });

  contentConfig.apis = apis;
  contentConfig.columns = beforeColumns.concat(afterColumns);

  return {
    contentConfig
  };
}
