/* eslint-disable prettier/prettier */
import { BeforeRequestType, ContentConfig } from "/@/components/PageContent";

import { addition, division } from "/@/utils/calc";
import { createTooltip } from "/@/utils/tootip";
import apis from "./apis";

function unit2TenThousand(value) {
  if (value === "NaN" || Number(value) === 0) return "0";
  if ((value < 1000 && value > 0) || (value < 0 && value > -1000)) return value;
  return division(value, 10000).toFixed(2) + "W";
}

const columns = [
  {
    label: "业务公司",
    prop: "depart",
    cellRenderer({ row }) {
      return row.depart === '总计' ? row.depart : row.depart.split("@")[1]
    }
  },
  {
    label: "平台公司",
    prop: "companyName",
    width: ' 140px'
  },
  {
    label: "应收账款",
    prop: "wpay_fee",
    cellRenderer({ row }) {
      return Number(row.wpay_fee).toFixed(2)
    }
  },
  {
    label: "已开票",
    prop: "ainv_fee",
    cellRenderer({ row }) {
      return Number(row.ainv_fee).toFixed(2)
    }
  },
  {
    label: "已回款",
    prop: "apay_fee",
    cellRenderer({ row }) {
      return Number(row.apay_fee).toFixed(2)
    }
  },
  {
    label: "已开票-已回款",
    prop: "ainv_apay_fee",
    cellRenderer({ row }) {
      return Number(row.ainv_apay_fee).toFixed(2)
    }
  },
  {
    label: "未开票",
    prop: "winv_fee",
    cellRenderer({ row }) {
      return Number(row.winv_fee).toFixed(2)
    }
  },
  {
    label: "待开票",
    prop: "inv_fee",
    cellRenderer({ row }) {
      return Number(row.inv_fee).toFixed(2)
    }
  },
  {
    label: "已发货未开票",
    prop: "winv_asend_fee",
    cellRenderer({ row }) {
      return Number(row.winv_asend_fee).toFixed(2)
    }
  },
  {
    label: "未发货",
    prop: "wpay_send_fee",
    cellRenderer({ row }) {
      return Number(row.wpay_send_fee).toFixed(2)
    }

  },
  {
    label: "超60天已发货未开票",
    prop: "winv_two_month",
    cellRenderer({ row }) {
      return Number(row.winv_two_month).toFixed(2)
    }
  },
  {
    label: "超180天应收账款",
    prop: "wpay_six_month",
    cellRenderer({ row }) {
      return Number(row.wpay_six_month).toFixed(2)
    }
  }
];

const contentConfig: ContentConfig = {
  columns,
  responseCode: 0,
  root: true,
  handleData(data = []) {

    const list = []
    return new Promise(resolve => {
      const result = data.map(item => {
        const total = item.reduce((prev, current) => ({
          depart: '总计',
          companyName: current.companyName,
          wpay_fee: Number(addition(current.wpay_fee, prev.wpay_fee)).toFixed(2),
          wpay_ainv_fee: Number(addition(current.wpay_ainv_fee, prev.wpay_ainv_fee)).toFixed(2),
          ainv_fee: Number(addition(current.ainv_fee, prev.ainv_fee)).toFixed(2),
          apay_fee: Number(addition(current.apay_fee, prev.apay_fee)).toFixed(2),
          ainv_apay_fee: Number(addition(current.ainv_apay_fee, prev.ainv_apay_fee)).toFixed(2),
          wpay_send_fee: Number(addition(current.wpay_send_fee, prev.wpay_send_fee)).toFixed(2),
          winv_fee: Number(addition(current.winv_fee, prev.winv_fee)).toFixed(2),
          inv_fee: Number(addition(current.inv_fee, prev.inv_fee)).toFixed(2),
          winv_asend_fee: Number(addition(current.winv_asend_fee, prev.winv_asend_fee)).toFixed(2),
          winv_two_month: Number(addition(current.winv_two_month, prev.winv_two_month)).toFixed(2),
          wpay_six_month: Number(addition(current.wpay_six_month, prev.wpay_six_month)).toFixed(2),
        }), {
          "depart": "",
          "companyName": "",
          "wpay_fee": 0,
          "wpay_ainv_fee": 0,
          "ainv_fee": 0,
          "apay_fee": 0,
          "ainv_apay_fee": 0,
          "wpay_send_fee": 0,
          "winv_fee": 0,
          "inv_fee": 0,
          "winv_asend_fee": 0,
          "winv_two_month": 0,
          "wpay_six_month": 0
        })

        list.push(...[total, ...item])
      })

      resolve(list)
    })
  },
  tableRowClassName(options) {
    if (options.row.depart === '总计') {
      return "warning-row"
    }
  },
  superUserNoAction: false,
  apis: { httpList: apis.list }
};

export default contentConfig;
